optimizely_flutter_sdk library


Copyright 2022-2023, Optimizely, Inc. and contributors * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software * distributed under the License is distributed on an "AS IS" BASIS, * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. * See the License for the specific language governing permissions and * limitations under the License. * **************************************************************************/

Classes

CmabConfig
Configuration for CMAB (Contextual Multi-Armed Bandit) service
DatafileHostOptions
Decision
DecisionListenerResponse
EventOptions
LogEventListenerResponse
OptimizelyDecisionContext
OptimizelyFlutterSdk
The main client class for the Optimizely Flutter SDK.
OptimizelyForcedDecision
OptimizelyLogger
OptimizelyUserContext
An object for user contexts that the SDK will use to make decisions for.
SDKSettings
TrackListenerResponse

Enums

ClientPlatform
ListenerType
OptimizelyDecideOption
Options controlling flag decisions.
OptimizelyLogLevel
OptimizelySegmentOption
Options controlling audience segments.