OptimizelyDecideOption enum

Options controlling flag decisions.

Inheritance
Available extensions

Values

disableDecisionEvent → const OptimizelyDecideOption

disable decision event tracking.

enabledFlagsOnly → const OptimizelyDecideOption

return decisions only for flags which are enabled (decideAll only).

ignoreUserProfileService → const OptimizelyDecideOption

skip user profile service for decision.

includeReasons → const OptimizelyDecideOption

include info and debug messages in the decision reasons.

excludeVariables → const OptimizelyDecideOption

exclude variable values from the decision result.

ignoreCmabCache → const OptimizelyDecideOption

ignore CMAB cache (bypass cache, make fresh request).

resetCmabCache → const OptimizelyDecideOption

reset entire CMAB cache.

invalidateUserCmabCache → const OptimizelyDecideOption

invalidate CMAB cache for current user only.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OptimizelyDecideOption>
A constant List of the values in this enum, in order of their declaration.