SDKSettings class


Copyright 2023, Optimizely, Inc. and contributors * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software * distributed under the License is distributed on an "AS IS" BASIS, * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. * See the License for the specific language governing permissions and * limitations under the License. * **************************************************************************/

Constructors

SDKSettings({int segmentsCacheSize = 100, int segmentsCacheTimeoutInSecs = 600, int timeoutForSegmentFetchInSecs = 10, int timeoutForOdpEventInSecs = 10, bool disableOdp = false, bool enableVuid = false})
const

Properties

disableOdp bool
final
enableVuid bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentsCacheSize int
final
segmentsCacheTimeoutInSecs int
final
timeoutForOdpEventInSecs int
final
timeoutForSegmentFetchInSecs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited